@@ -27,21 +27,24 @@
  * SUCH DAMAGE.
  */
 
-#if 0
-static char sccsid[] = "@(#)getttyent.c	8.1 (Berkeley) 6/4/93";
-#endif
-
+#define _GNU_SOURCE
+#include <features.h>
 #include <ttyent.h>
 #include <stdio.h>
 #include <stdio_ext.h>
 #include <ctype.h>
 #include <string.h>
+#include <stdlib.h>
+#ifdef __UCLIBC_HAS_THREADS__
+#include <pthread.h>
+#endif
 
 static char zapchar;
 static FILE *tf;
+static struct ttyent tty;
 
-struct ttyent *
-getttynam(const char *tty)
+
+struct ttyent * getttynam(const char *tty)
 {
     register struct ttyent *t;
 
@@ -53,23 +56,69 @@ getttynam(const char *tty)
     return (t);
 }
 
-static char *skip __P((char *));
-static char *value __P((char *));
 
-struct ttyent * getttyent()
+/* Skip over the current field, removing quotes, and return 
+ * a pointer to the next field.
+ */
+#define	QUOTED	1
+static char * skip(register char *p)
+{
+    register char *t;
+    register int c, q;
+
+    for (q = 0, t = p; (c = *p) != '\0'; p++) {
+	if (c == '"') {
+	    q ^= QUOTED;	/* obscure, but nice */
+	    continue;
+	}
+	if (q == QUOTED && *p == '\\' && *(p+1) == '"')
+	    p++;
+	*t++ = *p;
+	if (q == QUOTED)
+	    continue;
+	if (c == '#') {
+	    zapchar = c;
+	    *p = 0;
+	    break;
+	}
+	if (c == '\t' || c == ' ' || c == '\n') {
+	    zapchar = c;
+	    *p++ = 0;
+	    while ((c = *p) == '\t' || c == ' ' || c == '\n')
+		p++;
+	    break;
+	}
+    }
+    *--t = '\0';
+    return (p);
+}
+
+static char * value(register char *p)
+{
+
+    return ((p = index(p, '=')) ? ++p : NULL);
+}
+
+struct ttyent * getttyent(void)
 {
-    static struct ttyent tty;
     register int c;
     register char *p;
-#define	MAXLINELENGTH	100
-    static char line[MAXLINELENGTH];
+    static char *line = NULL;
 
     if (!tf && !setttyent())
 	return (NULL);
-    flockfile (tf);
+
+    if (!line) {
+            line = malloc(BUFSIZ);
+		if (!line)
+		    abort();
+    }
+
+	__STDIO_ALWAYS_THREADLOCK(tf);
+
     for (;;) {
-	if (!fgets_unlocked(p = line, sizeof(line), tf)) {
-	    funlockfile (tf);
+	if (!fgets_unlocked(p = line, BUFSIZ, tf)) {
+		__STDIO_ALWAYS_THREADUNLOCK(tf);
 	    return (NULL);
 	}
 	/* skip lines that are too big */
@@ -114,7 +163,7 @@ struct ttyent * getttyent()
 	    break;
     }
     /* We can release the lock only here since `zapchar' is global.  */
-    funlockfile(tf);
+	__STDIO_ALWAYS_THREADUNLOCK(tf);
 
     if (zapchar == '#' || *p == '#')
 	while ((c = *++p) == ' ' || c == '\t')
@@ -127,50 +176,6 @@ struct ttyent * getttyent()
     return (&tty);
 }
 
-#define	QUOTED	1
-
-/*
- * Skip over the current field, removing quotes, and return a pointer to
- * the next field.
- */
-static char * skip(register char *p)
-{
-    register char *t;
-    register int c, q;
-
-    for (q = 0, t = p; (c = *p) != '\0'; p++) {
-	if (c == '"') {
-	    q ^= QUOTED;	/* obscure, but nice */
-	    continue;
-	}
-	if (q == QUOTED && *p == '\\' && *(p+1) == '"')
-	    p++;
-	*t++ = *p;
-	if (q == QUOTED)
-	    continue;
-	if (c == '#') {
-	    zapchar = c;
-	    *p = 0;
-	    break;
-	}
-	if (c == '\t' || c == ' ' || c == '\n') {
-	    zapchar = c;
-	    *p++ = 0;
-	    while ((c = *p) == '\t' || c == ' ' || c == '\n')
-		p++;
-	    break;
-	}
-    }
-    *--t = '\0';
-    return (p);
-}
-
-static char * value(register char *p)
-{
-
-    return ((p = index(p, '=')) ? ++p : NULL);
-}
-
 int setttyent(void)
 {
 
